import{s as re,n as ne,o as ie}from"../chunks/scheduler.6062bdaf.js";import{S as ae,i as se,g as s,s as i,r as U,A as ce,h as c,f as o,c as a,j as V,u as F,x as T,k as B,y as u,a as n,v as A,d as R,t as W,w as j}from"../chunks/index.4bca734e.js";import{D as pe}from"../chunks/Docstring.81ba5e3c.js";import{H as oe,E as le}from"../chunks/EditOnGithub.74ab2baa.js";function ue(J){let l,P,y,k,d,C,m,M,r,h,G,v,K="Export a pre-trained PyTorch model to the ExecuTorch format using a specified recipe.",I,$,Q="This function facilitates the transformation of a PyTorch model into an optimized ExecuTorch program.",N,b,X="Notes:",O,w,Y="<li>The function uses a dynamic recipe discovery mechanism to identify and import the specified recipe.</li> <li>The exported model is stored in the specified output directory with the fixed filename <code>model.pte</code>.</li> <li>The resulting ExecuTorch program is serialized and saved to the output directory.</li>",H,x,Z=`The primary export function is designed to be <strong>model- and task-independent</strong> as well as <strong>optimization-agnostic</strong>, providing a
highly flexible and modular interface for exporting Hugging Face models to the ExecuTorch backend.`,L,f,ee=`This approach highlights the <strong>composability</strong> of ExecuTorch export pipeline, where dynamically registered <strong>task configurations</strong>
specify how a :hug model is prepared, and <strong>recipe configurations</strong> encapsulate device-specific optimizations during export. This
separation allows users to customize the export process without altering the core function.`,z,g,te='For more details on task and recipe configurations, see the <a href="./configuration.mdx">Configuration for ExecuTorch Export</a>.',D,_,q,E,S;return d=new oe({props:{title:"Export functions",local:"export-functions",headingTag:"h1"}}),m=new oe({props:{title:"Main functions",local:"optimum.exporters.executorch.export_to_executorch",headingTag:"h2"}}),h=new pe({props:{name:"optimum.exporters.executorch.export_to_executorch",anchor:"optimum.exporters.executorch.export_to_executorch",parameters:[{name:"model",val:": typing.Union[ForwardRef('PreTrainedModel'), ForwardRef('TorchExportableModuleWithStaticCache')]"},{name:"task",val:": str"},{name:"recipe",val:": str"},{name:"output_dir",val:": typing.Union[str, pathlib.Path]"},{name:"**kwargs",val:""}],parametersDescription:[{anchor:"optimum.exporters.executorch.export_to_executorch.model",description:`<strong>model</strong> (<code>Union[&quot;PreTrainedModel&quot;, &quot;TorchExportableModuleWithStaticCache&quot;]</code>) &#x2014;
A PyTorch model to be exported. This can be a standard HuggingFace <code>PreTrainedModel</code> or a wrapped
module like <code>TorchExportableModuleWithStaticCache</code> for text generation task.`,name:"model"},{anchor:"optimum.exporters.executorch.export_to_executorch.task",description:`<strong>task</strong> (<code>str</code>) &#x2014;
The specific task the exported model will perform, e.g., &#x201C;text-generation&#x201D;.`,name:"task"},{anchor:"optimum.exporters.executorch.export_to_executorch.recipe",description:`<strong>recipe</strong> (<code>str</code>) &#x2014;
The recipe to guide the export process, e.g., &#x201C;xnnpack&#x201D;. Recipes define the optimization and lowering steps.
Will raise an exception if the specified recipe is not registered in the recipe registry.`,name:"recipe"},{anchor:"optimum.exporters.executorch.export_to_executorch.output_dir",description:`<strong>output_dir</strong> (<code>Union[str, Path]</code>) &#x2014;
Path to the directory where the resulting ExecuTorch model will be saved.`,name:"output_dir"},{anchor:"optimum.exporters.executorch.export_to_executorch.*kwargs",description:`*<strong>*kwargs</strong> &#x2014;
Additional configuration options passed to the recipe.`,name:"*kwargs"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/executorch/convert.py#L38",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>The lowered ExecuTorch program object.</p>
`,returnType:`<script context="module">export const metadata = 'undefined';<\/script>


<p><code>ExecuTorchProgram</code></p>
`}}),_=new le({props:{source:"https://github.com/huggingface/optimum/blob/main/docs/source/exporters/executorch/package_reference/export.mdx"}}),{c(){l=s("meta"),P=i(),y=s("p"),k=i(),U(d.$$.fragment),C=i(),U(m.$$.fragment),M=i(),r=s("div"),U(h.$$.fragment),G=i(),v=s("p"),v.textContent=K,I=i(),$=s("p"),$.textContent=Q,N=i(),b=s("p"),b.textContent=X,O=i(),w=s("ul"),w.innerHTML=Y,H=i(),x=s("p"),x.innerHTML=Z,L=i(),f=s("p"),f.innerHTML=ee,z=i(),g=s("p"),g.innerHTML=te,D=i(),U(_.$$.fragment),q=i(),E=s("p"),this.h()},l(e){const t=ce("svelte-u9bgzb",document.head);l=c(t,"META",{name:!0,content:!0}),t.forEach(o),P=a(e),y=c(e,"P",{}),V(y).forEach(o),k=a(e),F(d.$$.fragment,e),C=a(e),F(m.$$.fragment,e),M=a(e),r=c(e,"DIV",{class:!0});var p=V(r);F(h.$$.fragment,p),G=a(p),v=c(p,"P",{"data-svelte-h":!0}),T(v)!=="svelte-awkbkm"&&(v.textContent=K),I=a(p),$=c(p,"P",{"data-svelte-h":!0}),T($)!=="svelte-b7ulc3"&&($.textContent=Q),N=a(p),b=c(p,"P",{"data-svelte-h":!0}),T(b)!=="svelte-1biq3pv"&&(b.textContent=X),O=a(p),w=c(p,"UL",{"data-svelte-h":!0}),T(w)!=="svelte-b1224a"&&(w.innerHTML=Y),p.forEach(o),H=a(e),x=c(e,"P",{"data-svelte-h":!0}),T(x)!=="svelte-1wa0tv3"&&(x.innerHTML=Z),L=a(e),f=c(e,"P",{"data-svelte-h":!0}),T(f)!=="svelte-tp4agm"&&(f.innerHTML=ee),z=a(e),g=c(e,"P",{"data-svelte-h":!0}),T(g)!=="svelte-6gokua"&&(g.innerHTML=te),D=a(e),F(_.$$.fragment,e),q=a(e),E=c(e,"P",{}),V(E).forEach(o),this.h()},h(){B(l,"name","hf:doc:metadata"),B(l,"content",de),B(r,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8")},m(e,t){u(document.head,l),n(e,P,t),n(e,y,t),n(e,k,t),A(d,e,t),n(e,C,t),A(m,e,t),n(e,M,t),n(e,r,t),A(h,r,null),u(r,G),u(r,v),u(r,I),u(r,$),u(r,N),u(r,b),u(r,O),u(r,w),n(e,H,t),n(e,x,t),n(e,L,t),n(e,f,t),n(e,z,t),n(e,g,t),n(e,D,t),A(_,e,t),n(e,q,t),n(e,E,t),S=!0},p:ne,i(e){S||(R(d.$$.fragment,e),R(m.$$.fragment,e),R(h.$$.fragment,e),R(_.$$.fragment,e),S=!0)},o(e){W(d.$$.fragment,e),W(m.$$.fragment,e),W(h.$$.fragment,e),W(_.$$.fragment,e),S=!1},d(e){e&&(o(P),o(y),o(k),o(C),o(M),o(r),o(H),o(x),o(L),o(f),o(z),o(g),o(D),o(q),o(E)),o(l),j(d,e),j(m,e),j(h),j(_,e)}}}const de='{"title":"Export functions","local":"export-functions","sections":[{"title":"Main functions","local":"optimum.exporters.executorch.export_to_executorch","sections":[],"depth":2}],"depth":1}';function me(J){return ie(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class _e extends ae{constructor(l){super(),se(this,l,me,ue,re,{})}}export{_e as component};
